@@ -1,12 +1,12 @@
 package Dist::Zilla::MintingProfile::Pcore;
 
 use Moose;
-use P;
+use Pcore;
 use Path::Class();
 
 with qw[Dist::Zilla::Role::MintingProfile];
 
-no P;
+no Pcore;
 no Moose;
 
 sub profile_dir ( $self, $profile_name ) {
