@@ -2,7 +2,7 @@
 
 package main v0.1.0;
 
-use P;
+use Pcore;
 use <: $module_name :>;
 
 1;
