@@ -2,7 +2,7 @@
 
 package main v0.1.0;
 
-use P;
+use Pcore;
 use Const::Fast();
 use Benchmark();
 
@@ -19,9 +19,9 @@ my $res;
 $res->{'Geo::IP'} = Benchmark::timeit( $COUNT, sub { my $a = P->geoip->country_code_by_addr('192.37.51.100') } );
 
 {
-    no warnings qw(once);    ## no critic qw(TestingAndDebugging::ProhibitNoWarnings)
+    no warnings qw[once];    ## no critic qw(TestingAndDebugging::ProhibitNoWarnings)
 
-    local $P::Util::GeoIP::GEOIP_PURE_PERL = 1;
+    local $Pcore::Util::GeoIP::GEOIP_PURE_PERL = 1;
 
     P->geoip->reconnect;
 
