@@ -2,7 +2,7 @@
 
 package main v0.1.0;
 
-use P;
+use Pcore;
 use Const::Fast();
 use Benchmark();
 
@@ -10,13 +10,13 @@ Const::Fast::const our $COUNT => -3;
 
 # benchmark regex operations with upgraded / downgraded UTF-8 scalar
 
-my $scalar_upgraded = q{abc£££££} x ( 1024 * 256 );
+my $scalar_upgraded = q[abc£££££] x ( 1024 * 256 );
 my $scalar_downgraded = $scalar_upgraded;
 utf8::downgrade($scalar_downgraded);
 
-say q{Bench regex speed for different scalar types: upgraded, downgraded};
-say q{Upgraded length: } . bytes::length($scalar_upgraded);
-say q{Downgraded length: } . bytes::length($scalar_downgraded);
+say q[Bench regex speed for different scalar types: upgraded, downgraded];
+say q[Upgraded length: ] . bytes::length($scalar_upgraded);
+say q[Downgraded length: ] . bytes::length($scalar_downgraded);
 
 my $res = Benchmark::timethese(
     $COUNT,
